@@ -2,4 +2,5 @@ from linora.utils._progbar import *
 from linora.utils._logger import *
 from linora.utils._config import *
 from linora.utils._schedulers import *
-from linora.utils import Message
\ No newline at end of file
+from linora.utils import message
+from linora.utils import compress
\ No newline at end of file
